<?php

namespace Raket\Mail\Policies;

use Litepie\User\Contracts\UserPolicy;
use Raket\Mail\Models\Mail;

class MailPolicy
{

    /**
     * Determine if the given user can view the mail.
     *
     * @param UserPolicy $user
     * @param Mail $mail
     *
     * @return bool
     */
    public function view(UserPolicy $user, Mail $mail)
    {
        if ($user->canDo('mail.mail.view') && $user->isAdmin()) {
            return true;
        }

        return $mail->user_id == user_id() && $mail->user_type == user_type();
    }

    /**
     * Determine if the given user can create a mail.
     *
     * @param UserPolicy $user
     * @param Mail $mail
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('mail.mail.create');
    }

    /**
     * Determine if the given user can update the given mail.
     *
     * @param UserPolicy $user
     * @param Mail $mail
     *
     * @return bool
     */
    public function update(UserPolicy $user, Mail $mail)
    {
        if ($user->canDo('mail.mail.edit') && $user->isAdmin()) {
            return true;
        }

        return $mail->user_id == user_id() && $mail->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given mail.
     *
     * @param UserPolicy $user
     * @param Mail $mail
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Mail $mail)
    {
        return $mail->user_id == user_id() && $mail->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given mail.
     *
     * @param UserPolicy $user
     * @param Mail $mail
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Mail $mail)
    {
        if ($user->canDo('mail.mail.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given mail.
     *
     * @param UserPolicy $user
     * @param Mail $mail
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Mail $mail)
    {
        if ($user->canDo('mail.mail.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
